@@ -18,6 +18,13 @@ pub mod cosmos {
         }
     }
 
+    /// Granting of arbitrary privileges from one account to another.
+    pub mod authz {
+        pub mod v1beta1 {
+            include!("prost/cosmos.authz.v1beta1.rs");
+        }
+    }
+
     /// Balances.
     pub mod bank {
         pub mod v1beta1 {
@@ -121,6 +128,13 @@ pub mod cosmos {
         }
     }
 
+    /// Allows accounts to grant fee allowances and to use fees from their accounts.
+    pub mod feegrant {
+        pub mod v1beta1 {
+            include!("prost/cosmos.feegrant.v1beta1.rs");
+        }
+    }
+
     /// Messages and services handling gentx's
     pub mod genutil {
         pub mod v1beta1 {
@@ -213,6 +227,10 @@ pub mod ibc {
             pub mod v1 {
                 include!("prost/ibc.applications.transfer.v1.rs");
             }
+
+            pub mod v2 {
+                include!("prost/ibc.applications.transfer.v2.rs");
+            }
         }
     }
 
@@ -246,6 +264,13 @@ pub mod ibc {
             }
         }
 
+        /// IBC port.
+        pub mod port {
+            pub mod v1 {
+                include!("prost/ibc.core.port.v1.rs");
+            }
+        }
+
         /// IBC types.
         pub mod types {
             pub mod v1 {
@@ -265,6 +290,10 @@ pub mod ibc {
             pub mod v1 {
                 include!("prost/ibc.lightclients.solomachine.v1.rs");
             }
+
+            pub mod v2 {
+                include!("prost/ibc.lightclients.solomachine.v2.rs");
+            }
         }
         pub mod tendermint {
             pub mod v1 {
